generate abstract method
Override this method to specify how to generate according to
the source file and the parsed unit of the abstract syntax tree.
Implementation
void generate(File file, CompilationUnit unit);
Override this method to specify how to generate according to
the source file and the parsed unit of the abstract syntax tree.
void generate(File file, CompilationUnit unit);